Column and Data Types — SQLAlchemy 1.4 Documentation

Release: 1.4.21 | Release Date: July 14, 2021

# SQLAlchemy 1.4 Documentation

# Column and Data Types

- Column and Data Types
  - Generic Types
  - SQL Standard and Multiple Vendor Types
  - Vendor-Specific Types
- Custom Types
  - Overriding Type Compilation
  - Augmenting Existing Types
  - TypeDecorator Recipes
    - Coercing Encoded Strings to Unicode
    - Rounding Numerics
    - Store Timezone Aware Timestamps as Timezone Naive UTC
    - Backend-agnostic GUID Type
    - Marshal JSON Strings
  - Applying SQL-level Bind/Result Processing
  - Redefining and Creating New Operators
  - Creating New Types
  - Working with Custom Types and Reflection
- Base Type API